#
# spec file for package eio
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           eio
Version:        1.7.4
Release:        11.1
Summary:        Extension of ecore for parallel io operations
License:        LGPL-2.1
Group:          System/Libraries
Url:            http://enlightenment.org/
Source:         %{name}-%{version}.tar.bz2
BuildRequires:  doxygen
BuildRequires:  ecore-devel >= %version
BuildRequires:  eina-devel >= %version
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  gzip
BuildRequires:  iputils
BuildRequires:  libtool
BuildRequires:  m4
BuildRequires:  pkgconfig
BuildRequires:  zlib
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Extension of ecore for parallel I/O operations. Part of Enlightenment Foundation Libraries.

%package -n libeio1
Summary:        Extension of ecore for parallel io operations
Group:          System/Libraries

%description -n libeio1
Extension of ecore for parallel I/O operations. Part of Enlightenment Foundation Libraries.

%package devel
Summary:        Eio devel package
Group:          Development/Libraries/C and C++
Requires:       ecore-devel >= %version
Requires:       eina-devel >= %version
Requires:       libeio1 = %{version}
BuildRequires:  glibc-devel

%description devel
Development files for eio package.

%package doc-html
Summary:        HTML documentation of Eio
Group:          Documentation/HTML

%description doc-html
Documentation of Eio library in form of HTML pages.

%package doc-man
Summary:        Man documentation of Eina
Group:          Documentation/Man

%description doc-man
Documentation of Eina library in form of man pages.

%prep
%setup -q

%build
# fake time used for documentation
FAKE_DOCDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y')
FAKE_DOCYEAR=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%Y')
FAKE_DOCDATETIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y %T')
sed -i "s/\$datetime/$FAKE_DOCDATETIME/g;s/\$date/$FAKE_DOCDATE/g;s/\$year/$FAKEDOCYEAR/g" doc/*.html

%configure  --disable-static --disable-silent-rules
make %{?_smp_mflags}
make doc

%install
make install DESTDIR="%{buildroot}"

# copy documentation manually
echo "Copying HTML documentation"
mkdir -p %{buildroot}%{_docdir}/%{name}
/bin/cp -vr doc/html %{buildroot}%{_docdir}/%{name}
echo "Copying MAN pages"
/bin/cp -vr doc/man/ %{buildroot}%{_mandir}/
# fix permissions
find %{buildroot}%{_docdir} -type f | xargs chmod 0644
find %{buildroot}%{_docdir} -type d | xargs chmod 0755
# remove duplicates
%if 0%{?suse_version}
%fdupes -s %{buildroot}%{_docdir}
%fdupes -s %{buildroot}%{_mandir}
%endif

find %{buildroot}%{_libdir} -name '*.la' -exec rm -v {} \;

%post -n libeio1 -p /sbin/ldconfig

%postun -n libeio1 -p /sbin/ldconfig

%files -n libeio1
%defattr(-,root,root)
%{_libdir}/libeio*so.1*

%files devel
%defattr(-,root,root)
%{_libdir}/pkgconfig/*
%{_includedir}/*
%{_libdir}/libeio.so

%files doc-html
%defattr(-, root, root)
%{_docdir}/%{name}

%files doc-man
%defattr(-, root, root)
%{_mandir}/*/*

%changelog
* Sat Dec 22 2012       Andrew Wyatt <andrew@fuduntu.org> - 1.7.4-11.1
- Built for Fuduntu

* Fri Dec 21 2012 sleep_walker@suse.cz
- update to 1.7.4
  Changes since Eio 1.7.3:
  - Fixed crash in eio_monitor_del.
  - Properly destroy fd on exec.
  - Add XML output to doc
  - Add installation rule for doc
* Thu Dec 20 2012 sleep_walker@suse.cz
- package also man pages
* Thu Dec 20 2012 sleep_walker@suse.cz
- build and package documentation
* Sat Dec  8 2012 simon@simotek.net
- Bump to 1.7.3
- 1.7.3 is a bugfix release to coincide with the beta release of efl
* Sat Nov 24 2012 sleep_walker@suse.cz
- require the same version or higher for EFL libraries
* Fri Nov 23 2012 simon@simotek.net
- bump to 1.7.2
  (No real changes - keep version synced with other EFL libraries)
* Thu Nov 22 2012 sleep_walker@suse.cz
- remove weird dependencies
* Thu Nov 22 2012 sleep_walker@suse.cz
- fix license
- spec file clean up
- remove autoupdate entries from changelog
- remove configure.ac file accidentally added to project
* Thu Nov 15 2012 sleep_walker@suse.cz
- remove autoreconf as it is not needed for release
* Tue Oct 23 2012 simon@simotek.net
- Update Spec file to match Nightly
* Sun Oct 21 2012 simon@simotek.net
- bump to 1.7.1
* Thu Mar 29 2012 sleep_walker@suse.cz
- fix devel package dependency
* Thu Mar 29 2012 sleep_walker@suse.cz
- rework to have libeio as subpackage, update to version 1.0.0
* Fri Nov  4 2011 tcech@suse.com
- remove `make doc' for now to workaround libpng doxygen dependency
  problem on SLE_10_SDK
* Fri Oct 21 2011 tcech@suse.com
- add eio-devel into provides of devel package
* Mon Oct 17 2011 tcech@suse.com
- fix CentOS 5 and SLES10 builds
* Mon Oct 10 2011 jreidinger@suse.com
- remove workaround as integrated by upstream
* Thu Oct  6 2011 tcech@suse.com
- workaround older autoconf version for older distros
* Wed Oct  5 2011 tcech@suse.com
- minor changes in spec file
* Tue Oct  4 2011 jreidinger@suse.com
- based on package from home:thidney:e17 project
- added to nightly builds
- spec file tweak
